==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/GremlinGraphResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Cosmos DB Gremlin graph resource object
 * @property analyticalStorageTtl Analytical TTL.
 * @property conflictResolutionPolicy The conflict resolution policy for the graph.
 * @property defaultTtl Default time to live
 * @property id Name of the Cosmos DB Gremlin graph
 * @property indexingPolicy The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
 * @property partitionKey The configuration of the partition key to be used for partitioning data into multiple partitions
 * @property uniqueKeyPolicy The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
 */
public data class GremlinGraphResourceArgs(
    public val analyticalStorageTtl: Output<Double>? = null,
    public val conflictResolutionPolicy: Output<ConflictResolutionPolicyArgs>? = null,
    public val defaultTtl: Output<Int>? = null,
    public val id: Output<String>,
    public val indexingPolicy: Output<IndexingPolicyArgs>? = null,
    public val partitionKey: Output<ContainerPartitionKeyArgs>? = null,
    public val uniqueKeyPolicy: Output<UniqueKeyPolicyArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs =
        com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs.builder()
            .analyticalStorageTtl(analyticalStorageTtl?.applyValue({ args0 -> args0 }))
            .conflictResolutionPolicy(
                conflictResolutionPolicy?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .defaultTtl(defaultTtl?.applyValue({ args0 -> args0 }))
            .id(id.applyValue({ args0 -> args0 }))
            .indexingPolicy(indexingPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .partitionKey(partitionKey?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .uniqueKeyPolicy(
                uniqueKeyPolicy?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [GremlinGraphResourceArgs].
 */
@PulumiTagMarker
public class GremlinGraphResourceArgsBuilder internal constructor() {
    private var analyticalStorageTtl: Output<Double>? = null

    private var conflictResolutionPolicy: Output<ConflictResolutionPolicyArgs>? = null

    private var defaultTtl: Output<Int>? = null

    private var id: Output<String>? = null

    private var indexingPolicy: Output<IndexingPolicyArgs>? = null

    private var partitionKey: Output<ContainerPartitionKeyArgs>? = null

    private var uniqueKeyPolicy: Output<UniqueKeyPolicyArgs>? = null

    /**
     * @param value Analytical TTL.
     */
    @JvmName("dlrqxswdduitterk")
    public suspend fun analyticalStorageTtl(`value`: Output<Double>) {
        this.analyticalStorageTtl = value
    }

    /**
     * @param value The conflict resolution policy for the graph.
     */
    @JvmName("owcqkuwescnucluu")
    public suspend fun conflictResolutionPolicy(`value`: Output<ConflictResolutionPolicyArgs>) {
        this.conflictResolutionPolicy = value
    }

    /**
     * @param value Default time to live
     */
    @JvmName("ndatujimsapijqqv")
    public suspend fun defaultTtl(`value`: Output<Int>) {
        this.defaultTtl = value
    }

    /**
     * @param value Name of the Cosmos DB Gremlin graph
     */
    @JvmName("owgmmfayuwhosswf")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("ybwsxnfwciyqjbgi")
    public suspend fun indexingPolicy(`value`: Output<IndexingPolicyArgs>) {
        this.indexingPolicy = value
    }

    /**
     * @param value The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("alktftdeqmtxuiah")
    public suspend fun partitionKey(`value`: Output<ContainerPartitionKeyArgs>) {
        this.partitionKey = value
    }

    /**
     * @param value The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("fejkipekiqbwmeyv")
    public suspend fun uniqueKeyPolicy(`value`: Output<UniqueKeyPolicyArgs>) {
        this.uniqueKeyPolicy = value
    }

    /**
     * @param value Analytical TTL.
     */
    @JvmName("oayqnymeiimyluhe")
    public suspend fun analyticalStorageTtl(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.analyticalStorageTtl = mapped
    }

    /**
     * @param value The conflict resolution policy for the graph.
     */
    @JvmName("mhwuyeditbjgknyl")
    public suspend fun conflictResolutionPolicy(`value`: ConflictResolutionPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.conflictResolutionPolicy = mapped
    }

    /**
     * @param argument The conflict resolution policy for the graph.
     */
    @JvmName("ksgufvtwoxhiserh")
    public suspend
    fun conflictResolutionPolicy(argument: suspend ConflictResolutionPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = ConflictResolutionPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.conflictResolutionPolicy = mapped
    }

    /**
     * @param value Default time to live
     */
    @JvmName("udemrdjrpjmurtme")
    public suspend fun defaultTtl(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultTtl = mapped
    }

    /**
     * @param value Name of the Cosmos DB Gremlin graph
     */
    @JvmName("amgfexxqmxtphnwv")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("rdpegoygnvarkndh")
    public suspend fun indexingPolicy(`value`: IndexingPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexingPolicy = mapped
    }

    /**
     * @param argument The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("beijjkjloljvituj")
    public suspend fun indexingPolicy(argument: suspend IndexingPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = IndexingPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.indexingPolicy = mapped
    }

    /**
     * @param value The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("tvnjlqetkfweevgp")
    public suspend fun partitionKey(`value`: ContainerPartitionKeyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partitionKey = mapped
    }

    /**
     * @param argument The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("siekhgspliggvmbn")
    public suspend fun partitionKey(argument: suspend ContainerPartitionKeyArgsBuilder.() -> Unit) {
        val toBeMapped = ContainerPartitionKeyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.partitionKey = mapped
    }

    /**
     * @param value The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("ysdpfbyyiagbssnw")
    public suspend fun uniqueKeyPolicy(`value`: UniqueKeyPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uniqueKeyPolicy = mapped
    }

    /**
     * @param argument The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("tclftgwftcfmhtws")
    public suspend fun uniqueKeyPolicy(argument: suspend UniqueKeyPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = UniqueKeyPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.uniqueKeyPolicy = mapped
    }

    internal fun build(): GremlinGraphResourceArgs = GremlinGraphResourceArgs(
        analyticalStorageTtl = analyticalStorageTtl,
        conflictResolutionPolicy = conflictResolutionPolicy,
        defaultTtl = defaultTtl,
        id = id ?: throw PulumiNullFieldException("id"),
        indexingPolicy = indexingPolicy,
        partitionKey = partitionKey,
        uniqueKeyPolicy = uniqueKeyPolicy,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/inputs/GremlinGraphResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin.inputs

import com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Cosmos DB Gremlin graph resource object
 * @property analyticalStorageTtl Analytical TTL.
 * @property conflictResolutionPolicy The conflict resolution policy for the graph.
 * @property defaultTtl Default time to live
 * @property id Name of the Cosmos DB Gremlin graph
 * @property indexingPolicy The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
 * @property partitionKey The configuration of the partition key to be used for partitioning data into multiple partitions
 * @property uniqueKeyPolicy The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
 */
public data class GremlinGraphResourceArgs(
    public val analyticalStorageTtl: Output<Double>? = null,
    public val conflictResolutionPolicy: Output<ConflictResolutionPolicyArgs>? = null,
    public val defaultTtl: Output<Int>? = null,
    public val id: Output<String>,
    public val indexingPolicy: Output<IndexingPolicyArgs>? = null,
    public val partitionKey: Output<ContainerPartitionKeyArgs>? = null,
    public val uniqueKeyPolicy: Output<UniqueKeyPolicyArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs =
        com.pulumi.azurenative.documentdb.inputs.GremlinGraphResourceArgs.builder()
            .analyticalStorageTtl(analyticalStorageTtl?.applyValue({ args0 -> args0 }))
            .conflictResolutionPolicy(
                conflictResolutionPolicy?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .defaultTtl(defaultTtl?.applyValue({ args0 -> args0 }))
            .id(id.applyValue({ args0 -> args0 }))
            .indexingPolicy(indexingPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .partitionKey(partitionKey?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .uniqueKeyPolicy(
                uniqueKeyPolicy?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [GremlinGraphResourceArgs].
 */
@PulumiTagMarker
public class GremlinGraphResourceArgsBuilder internal constructor() {
    private var analyticalStorageTtl: Output<Double>? = null

    private var conflictResolutionPolicy: Output<ConflictResolutionPolicyArgs>? = null

    private var defaultTtl: Output<Int>? = null

    private var id: Output<String>? = null

    private var indexingPolicy: Output<IndexingPolicyArgs>? = null

    private var partitionKey: Output<ContainerPartitionKeyArgs>? = null

    private var uniqueKeyPolicy: Output<UniqueKeyPolicyArgs>? = null

    /**
     * @param value Analytical TTL.
     */
    @JvmName("uoegrpnlyhevauuu")
    public suspend fun analyticalStorageTtl(`value`: Output<Double>) {
        this.analyticalStorageTtl = value
    }

    /**
     * @param value The conflict resolution policy for the graph.
     */
    @JvmName("slifsvmjrrtcvqqj")
    public suspend fun conflictResolutionPolicy(`value`: Output<ConflictResolutionPolicyArgs>) {
        this.conflictResolutionPolicy = value
    }

    /**
     * @param value Default time to live
     */
    @JvmName("sddkstjxcdwoemgr")
    public suspend fun defaultTtl(`value`: Output<Int>) {
        this.defaultTtl = value
    }

    /**
     * @param value Name of the Cosmos DB Gremlin graph
     */
    @JvmName("vtulhfkxslhqnatj")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("ybouweldngwwunrj")
    public suspend fun indexingPolicy(`value`: Output<IndexingPolicyArgs>) {
        this.indexingPolicy = value
    }

    /**
     * @param value The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("iotemsaynutkqdeg")
    public suspend fun partitionKey(`value`: Output<ContainerPartitionKeyArgs>) {
        this.partitionKey = value
    }

    /**
     * @param value The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("wprbsmxttwunjliu")
    public suspend fun uniqueKeyPolicy(`value`: Output<UniqueKeyPolicyArgs>) {
        this.uniqueKeyPolicy = value
    }

    /**
     * @param value Analytical TTL.
     */
    @JvmName("hkvorqmtiovcsuov")
    public suspend fun analyticalStorageTtl(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.analyticalStorageTtl = mapped
    }

    /**
     * @param value The conflict resolution policy for the graph.
     */
    @JvmName("qubujloiustsjvsw")
    public suspend fun conflictResolutionPolicy(`value`: ConflictResolutionPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.conflictResolutionPolicy = mapped
    }

    /**
     * @param argument The conflict resolution policy for the graph.
     */
    @JvmName("voinqkaulckwuuaf")
    public suspend
    fun conflictResolutionPolicy(argument: suspend ConflictResolutionPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = ConflictResolutionPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.conflictResolutionPolicy = mapped
    }

    /**
     * @param value Default time to live
     */
    @JvmName("facfyjivfvyoesie")
    public suspend fun defaultTtl(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultTtl = mapped
    }

    /**
     * @param value Name of the Cosmos DB Gremlin graph
     */
    @JvmName("ppgekpbdufrywdfy")
    public suspend fun id(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("ptgpjuryvjekknjd")
    public suspend fun indexingPolicy(`value`: IndexingPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.indexingPolicy = mapped
    }

    /**
     * @param argument The configuration of the indexing policy. By default, the indexing is automatic for all document paths within the graph
     */
    @JvmName("fcownhivkkahlhfd")
    public suspend fun indexingPolicy(argument: suspend IndexingPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = IndexingPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.indexingPolicy = mapped
    }

    /**
     * @param value The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("hlipjfqycadvigpy")
    public suspend fun partitionKey(`value`: ContainerPartitionKeyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partitionKey = mapped
    }

    /**
     * @param argument The configuration of the partition key to be used for partitioning data into multiple partitions
     */
    @JvmName("xgkpmoixswsyvsbh")
    public suspend fun partitionKey(argument: suspend ContainerPartitionKeyArgsBuilder.() -> Unit) {
        val toBeMapped = ContainerPartitionKeyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.partitionKey = mapped
    }

    /**
     * @param value The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("xwwikxlghpbqftyp")
    public suspend fun uniqueKeyPolicy(`value`: UniqueKeyPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.uniqueKeyPolicy = mapped
    }

    /**
     * @param argument The unique key policy configuration for specifying uniqueness constraints on documents in the collection in the Azure Cosmos DB service.
     */
    @JvmName("hfktodxocokrljuk")
    public suspend fun uniqueKeyPolicy(argument: suspend UniqueKeyPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = UniqueKeyPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.uniqueKeyPolicy = mapped
    }

    internal fun build(): GremlinGraphResourceArgs = GremlinGraphResourceArgs(
        analyticalStorageTtl = analyticalStorageTtl,
        conflictResolutionPolicy = conflictResolutionPolicy,
        defaultTtl = defaultTtl,
        id = id ?: throw PulumiNullFieldException("id"),
        indexingPolicy = indexingPolicy,
        partitionKey = partitionKey,
        uniqueKeyPolicy = uniqueKeyPolicy,
    )
}
